==> openshift-model-hive-6.7.2-sources.jar: io/fabric8/openshift/api/model/hive/v1/ControlPlaneServingCertificateSpecBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ControlPlaneServingCertificateSpecBuilder extends ControlPlaneServingCertificateSpecFluentImpl<ControlPlaneServingCertificateSpecBuilder> implements VisitableBuilder<ControlPlaneServingCertificateSpec,ControlPlaneServingCertificateSpecBuilder>{
  public ControlPlaneServingCertificateSpecBuilder() {
    this(false);
  }
  public ControlPlaneServingCertificateSpecBuilder(Boolean validationEnabled) {
    this(new ControlPlaneServingCertificateSpec(), validationEnabled);
  }
  public ControlPlaneServingCertificateSpecBuilder(ControlPlaneServingCertificateSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public ControlPlaneServingCertificateSpecBuilder(ControlPlaneServingCertificateSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ControlPlaneServingCertificateSpec(), validationEnabled);
  }
  public ControlPlaneServingCertificateSpecBuilder(ControlPlaneServingCertificateSpecFluent<?> fluent,ControlPlaneServingCertificateSpec instance) {
    this(fluent, instance, false);
  }
  public ControlPlaneServingCertificateSpecBuilder(ControlPlaneServingCertificateSpecFluent<?> fluent,ControlPlaneServingCertificateSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withAdditional(instance.getAdditional());
      fluent.withDefault(instance.getDefault());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ControlPlaneServingCertificateSpecBuilder(ControlPlaneServingCertificateSpec instance) {
    this(instance,false);
  }
  public ControlPlaneServingCertificateSpecBuilder(ControlPlaneServingCertificateSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withAdditional(instance.getAdditional());
      this.withDefault(instance.getDefault());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  ControlPlaneServingCertificateSpecFluent<?> fluent;
  Boolean validationEnabled;
  public ControlPlaneServingCertificateSpec build() {
    ControlPlaneServingCertificateSpec buildable = new ControlPlaneServingCertificateSpec(fluent.getAdditional(),fluent.getDefault());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-hive-6.8.0-sources.jar: io/fabric8/openshift/api/model/hive/v1/ControlPlaneServingCertificateSpecBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ControlPlaneServingCertificateSpecBuilder extends ControlPlaneServingCertificateSpecFluent<ControlPlaneServingCertificateSpecBuilder> implements VisitableBuilder<ControlPlaneServingCertificateSpec,ControlPlaneServingCertificateSpecBuilder>{
  public ControlPlaneServingCertificateSpecBuilder() {
    this(false);
  }
  public ControlPlaneServingCertificateSpecBuilder(Boolean validationEnabled) {
    this(new ControlPlaneServingCertificateSpec(), validationEnabled);
  }
  public ControlPlaneServingCertificateSpecBuilder(ControlPlaneServingCertificateSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public ControlPlaneServingCertificateSpecBuilder(ControlPlaneServingCertificateSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ControlPlaneServingCertificateSpec(), validationEnabled);
  }
  public ControlPlaneServingCertificateSpecBuilder(ControlPlaneServingCertificateSpecFluent<?> fluent,ControlPlaneServingCertificateSpec instance) {
    this(fluent, instance, false);
  }
  public ControlPlaneServingCertificateSpecBuilder(ControlPlaneServingCertificateSpecFluent<?> fluent,ControlPlaneServingCertificateSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new ControlPlaneServingCertificateSpec());

    if (instance != null) {
      fluent.withAdditional(instance.getAdditional());
      fluent.withDefault(instance.getDefault());
      fluent.withAdditional(instance.getAdditional());
      fluent.withDefault(instance.getDefault());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ControlPlaneServingCertificateSpecBuilder(ControlPlaneServingCertificateSpec instance) {
    this(instance,false);
  }
  public ControlPlaneServingCertificateSpecBuilder(ControlPlaneServingCertificateSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new ControlPlaneServingCertificateSpec());

    if (instance != null) {
      this.withAdditional(instance.getAdditional());
      this.withDefault(instance.getDefault());
      this.withAdditional(instance.getAdditional());
      this.withDefault(instance.getDefault());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  ControlPlaneServingCertificateSpecFluent<?> fluent;
  Boolean validationEnabled;
  public ControlPlaneServingCertificateSpec build() {
    ControlPlaneServingCertificateSpec buildable = new ControlPlaneServingCertificateSpec(fluent.buildAdditional(),fluent.getDefault());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
